/* ---------------------------------------------------------------
System       : MSDOS (etc)
Program      : lchop.c
Description  : A filter that chops (x) leading characters from the
               beginning of each line in a stream.

               Useful for chopping each line of a file with (x)
               unwanted leading characters prefixed on each line.

               Where (x) is a numeric value that is entered on
               the command line.

               lchop [infile.txt] (x)
               type [infile.txt] | lchop (x) > [outfile.txt]
               etc...

Written by   : Bill Buckels
Date Written : July 2000
Revision     : 1.1 First Release
--------------------------------------------------------------- */
#include <stdio.h>
#include <stdlib.h>

#define BUF_MAX  8192
#define BUF_SIZE (BUF_MAX + 1)

char cbuf[BUF_SIZE] = "\0";

void main(int argc, char **argv)
{
    int c, cnt = 0, lchop = 0, idx;
    FILE *fp = NULL;

    if (argc > 1) {
      fp = fopen(argv[1], "r");
      if (fp == NULL)
        lchop = atoi(argv[1]);

      if(argc > 2) {
         if (fp == NULL)
           fp = fopen(argv[2], "r");
         else
           lchop = atoi(argv[2]);
      }
    }

    for (;;) {
      if (NULL == fp)
        c = getchar();
      else
        c = fgetc(fp);

      if (c==EOF)break;
      if (c=='\r')continue;
      if (c==0)c = ' ';

      if (c == '\n' || cnt >= BUF_MAX) {
        for (idx = 0; cbuf[idx] != 0; idx++)
          if (idx >= lchop)
            putchar(cbuf[idx]);

        /* setup for next pass... */
        if (c == '\n') {
          putchar('\n');
          cbuf[0] = cnt = 0;
        }
        else {
          cbuf[0] = c;
          cbuf[1] = 0;
          cnt = 1;
        }
        continue;
      }

      cbuf[cnt] = c;
      cnt++; /* advance counter */
      cbuf[cnt] = 0;
    }
    if (cnt > 0) {
      for (idx = 0; cbuf[idx] != 0; idx++)
       if (idx >= lchop)
         putchar(cbuf[idx]);
      putchar('\n');
    }

    if (NULL != fp) {
      fclose(fp);
      exit(0);
    }
}
